% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MSCsimtester.R
\name{ADtest}
\alias{ADtest}
\title{Perform Anderson-Darling tests comparing sample and and theoretical pairwise distance distributions.}
\usage{
ADtest(distanceDensities, subsampleSize = FALSE)
}
\arguments{
\item{distanceDensities}{A list containing values needed for performing Anderson-Darling
test(s) on a gene tree sample, as output by \code{pairwiseDist}.
The first entry of this list is \code{sampleDist},
a vector with entries the pairwise distances computed from gene trees in a sample.
This can be useful to practitioners.  Other entries in this list are documented in the code
for \code{pairwiseDist}.}

\item{subsampleSize}{A positive integer or \code{FALSE}.  Default is \code{FALSE}, to use full sample for one test.}
}
\value{
Invisibly returns a sample from the theoretical density, of the same size as the empirical sample.
}
\description{
Takes as input theoretical pairwise distance densities under the MSC and
empirical pairwise distances from gene trees in a sample, as returned by
the function \code{pairwiseDist}.  Uses the package \code{kSamples} to perform
either one test on the entire dataset or multiple tests on subsamples.
}
\details{
Anderson-Darling tests can perform poorly due to numerical issues when the sample size N is too large, so
an optional parameter \code{subsampleSize} can be set to create subsamples of smaller size.
If \code{subsampleSize} is a positive integer, the sample of N gene trees
is partitioned into sets of size \code{subsampleSize}.
Anderson-Darling tests are performed on each subset, comparing them to
a random sample of the same size from the theoretical distribution.

For a single test, output of test statistics and p-values are given as text. For multiple tests,
output is given as a histogram of p-values. Assuming good fit, the histogram should be
approximately uniform.

The Anderson-Darling test compares the empirical distance distribution for the supplied gene tree
sample to a sample drawn from the theoretical distribution. The output from the \code{kSamples} package
will thus say 2 samples are being compared, to test a null-hypothesis that they come from the same distribution.
See \code{kSamples} documentation for more details.
Repeated runs of this function will give different results, since the sample from the theoretical distribution
will vary from run to run. Under the null hypothesis p-values for different runs should be approximately
uniformly distibuted.
}
\examples{
stree=read.tree(text="((((a:10000,b:10000):10000,c:20000):10000,d:30000):10000,e:40000);")
pops=c(15000,25000,10000,1,1,1,1,1,12000)
gts=read.tree(file=system.file("genetreeSample",package="MSCsimtester"))
distDen=pairwiseDist(stree,pops,gts,"a","b")
ADtest(distDen)
ADtest(distDen,1000)

}
\seealso{
\code{\link{pairwiseDist}}, \code{\link{kSamples-package}}
}
