% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MSCsimtester.R
\name{pairwiseDist}
\alias{pairwiseDist}
\title{Compute and plot pairwise distance densities.}
\usage{
pairwiseDist(stree, popSizes, gtSample, taxon1, taxon2, numSteps = 1000,
  tailProb = 0.01)
}
\arguments{
\item{stree}{An object of class \code{phylo} containing a rooted metric species tree. Edge lengths are in
number of generations.}

\item{popSizes}{An ordered list containing constant population sizes, one entry for each
population in the species tree, for a haploid population.  Sizes should be doubled for diploids.
If \code{stree} has k edges, then \code{popSizes} must have k+1 elements, with final entry
the size of the population ancestral to the root.}

\item{gtSample}{An object of class \code{multiPhylo} holding a sample of gene trees from a simulation.
Taxon labels on gene trees must be identical to those on \code{stree}.}

\item{taxon1}{A string specifying one taxon on \code{stree}.}

\item{taxon2}{A string specifying a second taxon on \code{stree}, distinct
from \code{taxon1}.}

\item{numSteps}{A positive integer giving the number of values on the x-axis to be sampled for creating
and graphing the theoretical pairwise distance density.  Default is \code{numSteps = 1000}.
Increasing this value will smooth the plot of the theoretical pairwise distance density.}

\item{tailProb}{The theoretical pairwise distance will be plotted from (0, xMax).  The maximum
value xMax is either the maximum pairwise distance in the gene tree sample or the x-value subtending a
probability of \code{tailProb} under the pdf.  Default is .01.}
}
\value{
A list of items needed for Anderson-Darling test(s), for use by \code{ADtest}. See function code for more details.
}
\description{
Computes theoretical pairwise distance densities under the MSC and empirical pairwise distances from
gene trees in a sample. A histogram of empirical values is plotted over the theoretical pdf.
}
\details{
\code{numSteps} equally spaced points will be sampled for creating
the theoretical pairwise distance density.  Default is \code{numSteps = 1000}.
}
\examples{
stree=read.tree(text="((((a:10000,b:10000):10000,c:20000):10000,d:30000):10000,e:40000);")
pops=c(15000,25000,10000,1,1,1,1,1,12000)
gts=read.tree(file=system.file("genetreeSample",package="MSCsimtester"))
pairwiseDist(stree,pops,gts,"a","b")

}
\seealso{
\code{\link{edgeOrder}}, \code{\link{plotPops}}, \code{\link{ADtest}}
}
